@@ -24,15 +24,15 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Iterator, List
+from typing import Iterator, List, Union
 
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
 from .type_defs import (
-    ListJobRunsResponseTypeDef,
-    ListManagedEndpointsResponseTypeDef,
-    ListVirtualClustersResponseTypeDef,
+    ListJobRunsResponseResponseTypeDef,
+    ListManagedEndpointsResponseResponseTypeDef,
+    ListVirtualClustersResponseResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -47,49 +47,52 @@ __all__ = ("ListJobRunsPaginator", "ListManagedEndpointsPaginator", "ListVirtual
 
 class ListJobRunsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
     """
 
     def paginate(
         self,
         *,
         virtualClusterId: str,
-        createdBefore: datetime = None,
-        createdAfter: datetime = None,
+        createdBefore: Union[datetime, str] = None,
+        createdAfter: Union[datetime, str] = None,
         name: str = None,
         states: List[JobRunStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListJobRunsResponseTypeDef]:
+    ) -> Iterator[ListJobRunsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
 
 class ListManagedEndpointsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
     """
 
     def paginate(
         self,
         *,
         virtualClusterId: str,
-        createdBefore: datetime = None,
-        createdAfter: datetime = None,
+        createdBefore: Union[datetime, str] = None,
+        createdAfter: Union[datetime, str] = None,
         types: List[str] = None,
         states: List[EndpointStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListManagedEndpointsResponseTypeDef]:
+    ) -> Iterator[ListManagedEndpointsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
 
 class ListVirtualClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
     """
 
     def paginate(
@@ -97,12 +100,12 @@ class ListVirtualClustersPaginator(Boto3Paginator):
         *,
         containerProviderId: str = None,
         containerProviderType: Literal["EKS"] = None,
-        createdAfter: datetime = None,
-        createdBefore: datetime = None,
+        createdAfter: Union[datetime, str] = None,
+        createdBefore: Union[datetime, str] = None,
         states: List[VirtualClusterStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListVirtualClustersResponseTypeDef]:
+    ) -> Iterator[ListVirtualClustersResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
